==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/grph2/ucpack/ucyayr.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__2 = 2;
static integer c__1 = 1;
static integer c__0 = 0;
static logical c_true = TRUE_;
static integer c__4 = 4;

/* ----------------------------------------------------------------------- */
/*     UCYAYR : PLOT YEAR AXIS */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int ucyayr_(char *cside, integer *jd0, integer *nd, ftnlen 
	cside_len)
{
    /* System generated locals */
    address a__1[2];
    integer i__1, i__2[2];
    real r__1;
    char ch__1[7];
    icilist ici__1;

    /* Builtin functions */
    integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
	    ;
    /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);

    /* Local variables */
    static integer i__;
    static char ch[4*50];
    static integer nn;
    static real uy[50];
    static integer id0, mo0, iy0, idi, moi, iyi, iyl, itdi;
    extern /* Subroutine */ int cladj_(char *, ftnlen);
    static logical label;
    extern /* Subroutine */ int date13_(integer *, integer *, integer *, 
	    integer *), date32_(integer *, integer *, integer *, integer *);
    static integer icent, irota, irotc;
    static logical lbtwn;
    extern /* Subroutine */ int datef3_(integer *, integer *, integer *, 
	    integer *, integer *, integer *, integer *);
    static real rtick2;
    extern integer ndyear_(integer *);
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen);
    extern logical luychk_(char *, ftnlen);
    extern /* Subroutine */ int uziget_(char *, integer *, ftnlen), uyplbl_(
	    char *, integer *, real *, char *, integer *, integer *, ftnlen, 
	    ftnlen), uzlget_(char *, logical *, ftnlen), uzrget_(char *, real 
	    *, ftnlen), uziset_(char *, integer *, ftnlen), uzlset_(char *, 
	    logical *, ftnlen), uypaxs_(char *, integer *, ftnlen), uyptmk_(
	    char *, integer *, real *, integer *, ftnlen), uzrset_(char *, 
	    real *, ftnlen);

    if (! luychk_(cside, (ftnlen)1)) {
	msgdmp_("E", "UCYAYR", "SIDE PARAMETER IS INVALID.", (ftnlen)1, (
		ftnlen)6, (ftnlen)26);
    }
    if (*jd0 < 0) {
	msgdmp_("E", "UCYAYR", "FIRST DATE IS LESS THAN 0.", (ftnlen)1, (
		ftnlen)6, (ftnlen)26);
    }
    if (*nd <= 0) {
	msgdmp_("E", "UCYAYR", "DATE LENGTH IS LESS THAN 0.", (ftnlen)1, (
		ftnlen)6, (ftnlen)27);
    }
    uypaxs_(cside, &c__2, (ftnlen)1);
    nn = 1;
    uy[nn - 1] = 0.f;
    date13_(jd0, &iy0, &mo0, &id0);
    i__1 = *nd;
    for (i__ = 1; i__ <= i__1; ++i__) {
	datef3_(&i__, &iy0, &mo0, &id0, &iyi, &moi, &idi);
	date32_(&iyi, &moi, &idi, &itdi);
	iyl = ndyear_(&iyi);
	if (itdi == iyl || i__ == *nd) {
	    ++nn;
	    uy[nn - 1] = (real) i__;
	    ici__1.icierr = 0;
	    ici__1.icirnum = 1;
	    ici__1.icirlen = 4;
	    ici__1.iciunit = ch + (nn - 2 << 2);
	    ici__1.icifmt = "(I4)";
	    s_wsfi(&ici__1);
	    do_fio(&c__1, (char *)&iyi, (ftnlen)sizeof(integer));
	    e_wsfi();
	    cladj_(ch + (nn - 2 << 2), (ftnlen)4);
	}
/* L10: */
    }
    if (nn > 50) {
	msgdmp_("E", "UCYAYR", "WORKING AREA IS NOT ENOUGH.", (ftnlen)1, (
		ftnlen)6, (ftnlen)27);
    }
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "ICENTY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziget_(ch__1, &icent, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "IROTLY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziget_(ch__1, &irota, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "IROTCY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziget_(ch__1, &irotc, (ftnlen)7);
    uzlget_("LBTWN", &lbtwn, (ftnlen)5);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "ICENTY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziset_(ch__1, &c__0, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "IROTLY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziset_(ch__1, &irotc, (ftnlen)7);
    uzlset_("LBTWN", &c_true, (ftnlen)5);
    uzrget_("RSIZET2", &rtick2, (ftnlen)7);
    r__1 = rtick2 * 1.5f;
    uzrset_("RSIZET2", &r__1, (ftnlen)7);
    uyptmk_(cside, &c__2, uy, &nn, (ftnlen)1);
    uzrset_("RSIZET2", &rtick2, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "LABELY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uzlget_(ch__1, &label, (ftnlen)7);
    if (label) {
	uyplbl_(cside, &c__2, uy, ch, &c__4, &nn, (ftnlen)1, (ftnlen)4);
    }
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "ICENTY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziset_(ch__1, &icent, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "IROTLY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziset_(ch__1, &irota, (ftnlen)7);
    uzlset_("LBTWN", &lbtwn, (ftnlen)5);
    return 0;
} /* ucyayr_ */

==> dcl-c_5.3-20050523-1.tar.gz: dcl-c-5.3-20050523/src/grph2/ucpack/ucyayr.c <==
/* src/grph2/ucpack/ucyayr.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__2 = 2;
static integer c__1 = 1;
static integer c__0 = 0;
static logical c_true = TRUE_;
static integer c__4 = 4;

/* ----------------------------------------------------------------------- */
/*     UCYAYR : PLOT YEAR AXIS */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int ucyayr_(char *cside, integer *jd0, integer *nd, ftnlen 
	cside_len)
{
    /* System generated locals */
    address a__1[2];
    integer i__1, i__2[2];
    real r__1;
    char ch__1[7];
    icilist ici__1;

    /* Builtin functions */
    integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
	    ;
    /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);

    /* Local variables */
    static integer i__;
    static char ch[4*50];
    static integer nn;
    static real uy[50];
    static integer id0, mo0, iy0, idi, moi, iyi, iyl, itdi;
    extern /* Subroutine */ int cladj_(char *, ftnlen);
    static logical label;
    extern /* Subroutine */ int date13_(integer *, integer *, integer *, 
	    integer *), date32_(integer *, integer *, integer *, integer *);
    static integer icent, irota, irotc;
    static logical lbtwn;
    extern /* Subroutine */ int datef3_(integer *, integer *, integer *, 
	    integer *, integer *, integer *, integer *);
    static real rtick2;
    extern integer ndyear_(integer *);
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen);
    extern logical luychk_(char *, ftnlen);
    extern /* Subroutine */ int uziget_(char *, integer *, ftnlen), uyplbl_(
	    char *, integer *, real *, char *, integer *, integer *, ftnlen, 
	    ftnlen), uzlget_(char *, logical *, ftnlen), uzrget_(char *, real 
	    *, ftnlen), uziset_(char *, integer *, ftnlen), uzlset_(char *, 
	    logical *, ftnlen), uypaxs_(char *, integer *, ftnlen), uyptmk_(
	    char *, integer *, real *, integer *, ftnlen), uzrset_(char *, 
	    real *, ftnlen);

    if (! luychk_(cside, (ftnlen)1)) {
	msgdmp_("E", "UCYAYR", "SIDE PARAMETER IS INVALID.", (ftnlen)1, (
		ftnlen)6, (ftnlen)26);
    }
    if (*jd0 < 0) {
	msgdmp_("E", "UCYAYR", "FIRST DATE IS LESS THAN 0.", (ftnlen)1, (
		ftnlen)6, (ftnlen)26);
    }
    if (*nd <= 0) {
	msgdmp_("E", "UCYAYR", "DATE LENGTH IS LESS THAN 0.", (ftnlen)1, (
		ftnlen)6, (ftnlen)27);
    }
    uypaxs_(cside, &c__2, (ftnlen)1);
    nn = 1;
    uy[nn - 1] = 0.f;
    date13_(jd0, &iy0, &mo0, &id0);
    i__1 = *nd;
    for (i__ = 1; i__ <= i__1; ++i__) {
	datef3_(&i__, &iy0, &mo0, &id0, &iyi, &moi, &idi);
	date32_(&iyi, &moi, &idi, &itdi);
	iyl = ndyear_(&iyi);
	if (itdi == iyl || i__ == *nd) {
	    ++nn;
	    uy[nn - 1] = (real) i__;
	    ici__1.icierr = 0;
	    ici__1.icirnum = 1;
	    ici__1.icirlen = 4;
	    ici__1.iciunit = ch + (nn - 2 << 2);
	    ici__1.icifmt = "(I4)";
	    s_wsfi(&ici__1);
	    do_fio(&c__1, (char *)&iyi, (ftnlen)sizeof(integer));
	    e_wsfi();
	    cladj_(ch + (nn - 2 << 2), (ftnlen)4);
	}
/* L10: */
    }
    if (nn > 50) {
	msgdmp_("E", "UCYAYR", "WORKING AREA IS NOT ENOUGH.", (ftnlen)1, (
		ftnlen)6, (ftnlen)27);
    }
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "ICENTY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziget_(ch__1, &icent, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "IROTLY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziget_(ch__1, &irota, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "IROTCY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziget_(ch__1, &irotc, (ftnlen)7);
    uzlget_("LBTWN", &lbtwn, (ftnlen)5);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "ICENTY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziset_(ch__1, &c__0, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "IROTLY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziset_(ch__1, &irotc, (ftnlen)7);
    uzlset_("LBTWN", &c_true, (ftnlen)5);
    uzrget_("RSIZET2", &rtick2, (ftnlen)7);
    r__1 = rtick2 * 1.5f;
    uzrset_("RSIZET2", &r__1, (ftnlen)7);
    uyptmk_(cside, &c__2, uy, &nn, (ftnlen)1);
    uzrset_("RSIZET2", &rtick2, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "LABELY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uzlget_(ch__1, &label, (ftnlen)7);
    if (label) {
	uyplbl_(cside, &c__2, uy, ch, &c__4, &nn, (ftnlen)1, (ftnlen)4);
    }
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "ICENTY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziset_(ch__1, &icent, (ftnlen)7);
/* Writing concatenation */
    i__2[0] = 6, a__1[0] = "IROTLY";
    i__2[1] = 1, a__1[1] = cside;
    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
    uziset_(ch__1, &irota, (ftnlen)7);
    uzlset_("LBTWN", &lbtwn, (ftnlen)5);
    return 0;
} /* ucyayr_ */
